@@ -27,8 +27,8 @@ class OutputStyleWidget : public QTreeWidget
   Q_OBJECT
 
   public:
-    OutputStyleWidget(QWidget *parent = 0);
-    ~OutputStyleWidget();
+    OutputStyleWidget(QWidget *parent = nullptr);
+    ~OutputStyleWidget() override;
 
     QTreeWidgetItem* addContext(const QString &key, const QString &name);
 
