@@ -32,11 +32,11 @@ KateProjectInfoViewCodeAnalysis::KateProjectInfoViewCodeAnalysis(KateProjectPlug
     : QWidget()
     , m_pluginView(pluginView)
     , m_project(project)
-    , m_messageWidget(0)
+    , m_messageWidget(nullptr)
     , m_startStopAnalysis(new QPushButton(i18n("Start Analysis...")))
     , m_treeView(new QTreeView())
     , m_model(new QStandardItemModel(m_treeView))
-    , m_analyzer(0)
+    , m_analyzer(nullptr)
 {
     /**
      * default style
@@ -74,8 +74,8 @@ KateProjectInfoViewCodeAnalysis::KateProjectInfoViewCodeAnalysis(KateProjectPlug
     /**
      * connect needed signals
      */
-    connect(m_startStopAnalysis, SIGNAL(clicked(bool)), this, SLOT(slotStartStopClicked()));
-    connect(m_treeView, SIGNAL(clicked(const QModelIndex &)), this, SLOT(slotClicked(const QModelIndex &)));
+    connect(m_startStopAnalysis, &QPushButton::clicked, this, &KateProjectInfoViewCodeAnalysis::slotStartStopClicked);
+    connect(m_treeView, &QTreeView::clicked, this, &KateProjectInfoViewCodeAnalysis::slotClicked);
 }
 
 KateProjectInfoViewCodeAnalysis::~KateProjectInfoViewCodeAnalysis()
@@ -100,9 +100,9 @@ void KateProjectInfoViewCodeAnalysis::slotStartStopClicked()
     m_analyzer = new QProcess(this);
     m_analyzer->setProcessChannelMode(QProcess::MergedChannels);
 
-    connect(m_analyzer, SIGNAL(readyRead()), this, SLOT(slotReadyRead()));
-    connect(m_analyzer, SIGNAL(finished(int, QProcess::ExitStatus)),
-            this, SLOT(finished(int, QProcess::ExitStatus)));
+    connect(m_analyzer, &QProcess::readyRead, this, &KateProjectInfoViewCodeAnalysis::slotReadyRead);
+    connect(m_analyzer, static_cast<void(QProcess::*)(int,QProcess::ExitStatus)>(&QProcess::finished),
+            this, &KateProjectInfoViewCodeAnalysis::finished);
 
     QStringList args;
     args << QStringLiteral("-q") << QStringLiteral("--inline-suppr") << QStringLiteral("--enable=all") << QStringLiteral("--template={file}////{line}////{severity}////{message}") << QStringLiteral("--file-list=-");
@@ -110,7 +110,7 @@ void KateProjectInfoViewCodeAnalysis::slotStartStopClicked()
 
     if (m_messageWidget) {
         delete m_messageWidget;
-        m_messageWidget = 0;
+        m_messageWidget = nullptr;
     }
 
     if (!m_analyzer->waitForStarted()) {
