@@ -29,7 +29,7 @@ KateProjectInfoViewIndex::KateProjectInfoViewIndex(KateProjectPluginView *plugin
     : QWidget()
     , m_pluginView(pluginView)
     , m_project(project)
-    , m_messageWidget(0)
+    , m_messageWidget(nullptr)
     , m_lineEdit(new QLineEdit())
     , m_treeView(new QTreeView())
     , m_model(new QStandardItemModel(m_treeView))
@@ -60,14 +60,15 @@ KateProjectInfoViewIndex::KateProjectInfoViewIndex(KateProjectPluginView *plugin
     layout->addWidget(m_lineEdit);
     layout->addWidget(m_treeView);
     setLayout(layout);
+    setFocusProxy(m_lineEdit);
 
     /**
      * connect needed signals
      */
-    connect(m_pluginView, SIGNAL(projectLookupWord(const QString &)), m_lineEdit, SLOT(setText(const QString &)));
-    connect(m_lineEdit, SIGNAL(textChanged(const QString &)), this, SLOT(slotTextChanged(const QString &)));
-    connect(m_treeView, SIGNAL(clicked(const QModelIndex &)), this, SLOT(slotClicked(const QModelIndex &)));
-    connect(m_project, SIGNAL(indexChanged()), this, SLOT(indexAvailable()));
+    connect(m_pluginView, &KateProjectPluginView::projectLookupWord, m_lineEdit, &QLineEdit::setText);
+    connect(m_lineEdit, &QLineEdit::textChanged, this, &KateProjectInfoViewIndex::slotTextChanged);
+    connect(m_treeView, &QTreeView::clicked, this, &KateProjectInfoViewIndex::slotClicked);
+    connect(m_project, &KateProject::indexChanged, this, &KateProjectInfoViewIndex::indexAvailable);
 
     /**
      * trigger once search with nothing
