@@ -34,12 +34,12 @@ class SearchDiskFiles: public QThread
     Q_OBJECT
 
 public:
-    SearchDiskFiles(QObject *parent = 0);
-    ~SearchDiskFiles();
+    SearchDiskFiles(QObject *parent = nullptr);
+    ~SearchDiskFiles() override;
 
     void startSearch(const QStringList &iles,
                      const QRegularExpression &regexp);
-    void run() Q_DECL_OVERRIDE;
+    void run() override;
 
     bool searching();
 
