@@ -51,7 +51,7 @@ class Results: public QWidget, public Ui::Results
 {
     Q_OBJECT
 public:
-    Results(QWidget *parent = 0);
+    Results(QWidget *parent = nullptr);
     int     matches;
     QRegularExpression regExp;
     bool    useRegExp;
@@ -72,7 +72,7 @@ Q_SIGNALS:
     void nextFocus(QWidget *currentWidget, bool *found, bool next);
 
 protected:
-    bool focusNextPrevChild (bool next) Q_DECL_OVERRIDE;
+    bool focusNextPrevChild (bool next) override;
 };
 
 
@@ -81,10 +81,10 @@ class KatePluginSearch : public KTextEditor::Plugin
     Q_OBJECT
 
 public:
-    explicit KatePluginSearch(QObject* parent = 0, const QList<QVariant>& = QList<QVariant>());
-    virtual ~KatePluginSearch();
+    explicit KatePluginSearch(QObject* parent = nullptr, const QList<QVariant>& = QList<QVariant>());
+    ~KatePluginSearch() override;
 
-    QObject *createView(KTextEditor::MainWindow *mainWindow) Q_DECL_OVERRIDE;
+    QObject *createView(KTextEditor::MainWindow *mainWindow) override;
 
 private:
     KateSearchCommand* m_searchCommand;
@@ -107,10 +107,10 @@ public:
     };
 
     KatePluginSearchView(KTextEditor::Plugin *plugin, KTextEditor::MainWindow *mainWindow, KTextEditor::Application* application);
-    ~KatePluginSearchView();
+    ~KatePluginSearchView() override;
 
-    void readSessionConfig (const KConfigGroup& config) Q_DECL_OVERRIDE;
-    void writeSessionConfig (KConfigGroup& config) Q_DECL_OVERRIDE;
+    void readSessionConfig (const KConfigGroup& config) override;
+    void writeSessionConfig (KConfigGroup& config) override;
 
 public Q_SLOTS:
     void startSearch();
@@ -164,6 +164,8 @@ private Q_SLOTS:
 
     void resultTabChanged(int index);
 
+    void expandResults();
+
     /**
      * keep track if the project plugin is alive and if the project file did change
      */
@@ -172,7 +174,7 @@ private Q_SLOTS:
     void slotProjectFileNameChanged ();
 
 protected:
-    bool eventFilter(QObject *obj, QEvent *ev) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *obj, QEvent *ev) override;
     void addHeaderItem();
 
 private:
@@ -227,8 +229,8 @@ Q_SIGNALS:
     //
 public:
     bool exec (KTextEditor::View *view, const QString &cmd, QString &msg,
-                      const KTextEditor::Range &range = KTextEditor::Range::invalid()) Q_DECL_OVERRIDE;
-    bool help (KTextEditor::View *view, const QString &cmd, QString &msg) Q_DECL_OVERRIDE;
+                      const KTextEditor::Range &range = KTextEditor::Range::invalid()) override;
+    bool help (KTextEditor::View *view, const QString &cmd, QString &msg) override;
 };
 
 #endif
