@@ -40,8 +40,8 @@ class KateMwModOnHdDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit KateMwModOnHdDialog(DocVector docs, QWidget *parent = 0, const char *name = 0);
-    ~KateMwModOnHdDialog();
+    explicit KateMwModOnHdDialog(DocVector docs, QWidget *parent = nullptr, const char *name = nullptr);
+    ~KateMwModOnHdDialog() override;
     void addDocument(KTextEditor::Document *doc);
 
 private Q_SLOTS:
@@ -64,8 +64,8 @@ private:
     bool m_blockAddDocument;
 
 protected:
-    virtual void closeEvent(QCloseEvent *e);
-    virtual void keyPressEvent(QKeyEvent *);
+    void closeEvent(QCloseEvent *e) override;
+    void keyPressEvent(QKeyEvent *) override;
 
 };
 
